var NAVTREE =
[
  [ "FLTK 1.3.4", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ad16daf120d9a0501cccaee563af0b9a3a7d2e5eb9247b1927ba5cc26dc82acaf3",
"Fl__Multiline__Input_8H_source.html",
"classFl__Browser.html#aeadc4b1c149e211228f0cfaaf9df929f",
"classFl__FLTK__File__Chooser.html#a43c23e477b1fa42daf6753cc84b8f3de",
"classFl__Graphics__Driver.html",
"classFl__Image.html#a149cf9b29d743fdd6adb4dd441e9095d",
"classFl__Native__File__Chooser.html#adcfb1c4830c3883c602343d2cfc44a73",
"classFl__Preferences.html#a20b8a66cd9fda6f727e391847653c4df",
"classFl__Slider.html#aeda9efe572a5151dca87b41ac98cd6e5",
"classFl__Text__Buffer.html#a12bfe32020ca2221a98455265b36e096",
"classFl__Text__Display.html#ad6288a3a93930c706c154ea065308c9d",
"classFl__Tree__Item.html",
"classFl__Value__Input.html#ae73dfcd7760e0f80dec4fecb9ad3d163",
"classFl__Wizard.html#a684252500c11e66e110713a82f85390b",
"fl__ask_8H.html#af2427850080f7b2ddc65f9a0f1e2067cadf3a64f31aaf6ba0c6b93a45da955feb",
"glut.html#glut_description",
"group__fl__drawings.html#ga6f6f1aea3b90a03c1714336e7aef349d",
"group__fl__unicode.html#ga82c145ba77cf3a650e0a0eb2f40e9766",
"structFl__Glut__StrokeChar.html#a270526ffef05a9d90fa321a972c80962"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';